import { registerTSPaths } from '../server/helpers/register-ts-paths'
registerTSPaths()

import { execCLI } from '@shared/extra-utils'

run()
  .then(() => process.exit(0))
  .catch(err => {
    console.error(err)
    process.exit(-1)
  })

async function run () {
  const blacklist = getContributorsBlacklist()

  {
    let contributors = await getGitContributors()
    contributors = contributors.concat(getZanataContributors())
    contributors = contributors.filter(c => blacklist[c.username] !== true)

    console.log('# Code & Translators contributors\n')
    for (const contributor of contributors) {
      console.log(` * ${contributor.username}`)
    }
  }

  {
    console.log('\n\n# Design\n')
    console.log(' * [Olivier Massain](https://dribbble.com/omassain)')
    console.log(' * [Marie-Cécile Godwin Paccard](https://mcgodwin.com/)')

    console.log('\n\n# Icons\n')
    console.log(' * [Feather Icons](feathericons.com/) (MIT)')
    console.log(' * `playlist add`, `history`, `subscriptions`, `miscellaneous-services.svg` by Material UI (Apache 2.0)')
    console.log(' * `support` by Chocobozzz (CC-BY)')
    console.log(' * `language` by Aaron Jin (CC-BY)')
    console.log(' * `video-language` by Rigel Kent (CC-BY)')
    console.log(' * `peertube-x` by Solen DP (CC-BY)')
  }

  {
    console.log('\n\n# Contributors to our 2020 crowdfunding :heart:\n')
    console.log(
      `*We ran [a crowdfunding campaign](https://joinpeertube.org/roadmap) in 2020 to implement live streaming to the version ` +
      `3.0.0 of PeerTube. Thanks to everyone who pitched in and shared the news!*\n\n`
    )

    console.log(get2020CrowdfundingContributors().join(', '))
  }

  {
    console.log('\n\n# Contributors to our 2018 crowdfunding :heart:')
    console.log(
      `\n*We ran [a crowdfunding campaign](https://www.kisskissbankbank.com/en/projects/peertube-a-free-and-federated-video-platform) ` +
      `in 2018 to pave the road to the version 1.0.0 of PeerTube, with 1,379 backers. ` +
      `Thanks to everyone who pitched in and shared the news!*\n\n`
    )

    console.log(get2018CrowdfundingContributors().join(', '))
  }
}

async function getGitContributors () {
  const output = await execCLI(`git --no-pager shortlog -sn < /dev/tty | sed 's/^\\s\\+[0-9]\\+\\s\\+//g'`)

  return output.split('\n')
               .filter(l => !!l)
               .map(l => ({ username: l }))
}

function get2020CrowdfundingContributors () {
  return [
    '0sw',
    '12b',
    '3141592',
    '3dsman',
    '3ym3r1c',
    '43',
    '4da',
    'Abi',
    'Adam',
    'Adedi',
    'adgl',
    'Adrien',
    'aenima',
    'Aerialtus',
    'aerogus',
    'Ahuka',
    'Al',
    'alainmi11',
    'Alastair',
    'alcalyn',
    'Alcyone',
    'aldatsa',
    'Alex',
    'Alexandre',
    'Alias',
    'Alxnbl',
    'Amael',
    'Amolith',
    'Anaël O .',
    'ancapepe',
    'andkit',
    'andor',
    'André',
    'André R',
    'Andy Cuccaro',
    'Ankur',
    'anoa',
    'anode',
    'Anonymous',
    'Antoine Linard',
    'Anton',
    'Anton Karmanov',
    'Antón López',
    'ao',
    'AObuchow',
    'AP37',
    'Aquarius',
    'Aqwuus',
    'arduinux',
    'Aris~',
    'Arlo James Barnes',
    'Armeclemes',
    'Armo0100101',
    'arnopoit',
    'Arthur',
    'Arvi89',
    'aukfood',
    'Aurélien',
    'Aurélien Marty',
    'Azelven',
    'azmeuk',
    'azure_source',
    'bacardi55',
    'Bakeneko',
    'Balix',
    'barjot-fou',
    'Bart',
    'Bast',
    'Baustube-GmbH',
    'bavier',
    'baza',
    'Ben',
    'BenBrrd',
    'Bene',
    'Benetj',
    'Benjamin Bellamy',
    'BenjaminBurgy',
    'Beppo74',
    'Berthold Depoele',
    'bher',
    'Bigaston',
    'bikepunk',
    'Black Winner Yoshi',
    'blipp',
    'blitz',
    'Bloodaxe',
    'bob_isat',
    'bodtx',
    'bolika',
    'Bolton',
    'Bonzux',
    'booleon',
    'Brackmeister',
    'brandkopf',
    'Bruno',
    'BueroBert',
    'c2ba',
    'caencamp',
    'Cairn',
    'cajad',
    'cambridgeport90',
    'CamilleB',
    'CC',
    'Cédric F .',
    'cequejevois',
    'cgeek',
    'chamar1',
    'charles',
    'Charles',
    'charly',
    'Chloons',
    'choj',
    'Chopanaweur',
    'Chosto',
    'choufleur',
    'chrisseiferth',
    'christian_u',
    'christophe .le',
    'Citoyen D_C .',
    'citronbleuv',
    'cl3f',
    'clacke',
    'Claichou',
    'clairette',
    'Clém',
    'clemdup',
    'Clénio',
    'Clifford',
    'clyde',
    'CODE LUTIN',
    'Coldguy',
    'ColinMaudry',
    'commagray',
    'CorentinBL',
    'coyotte508',
    'Cricri94',
    'Crocmagnon',
    'crossgolf_rebel',
    'CryoGen',
    'Cumbayah!',
    'Cyan Box',
    'Cyberdad ',
    'Cybernatus',
    'Cyril',
    'Cyril Waechter',
    'dada',
    'Daemons',
    'Daminou21',
    'Danfernbanck',
    'David',
    'davidak',
    'dawnbreak',
    'Debbie',
    'dehy',
    'delphin',
    'derrgis',
    'desianer',
    'Désidérius',
    'desttinghim',
    'Deuchnord',
    'DevAdrien',
    'dexp2',
    'DHeadshot',
    'dibetao',
    'dimdoum',
    'Dio94',
    'Diogo Constantino',
    'Djôdj',
    'dmantis',
    'dmi',
    'dnegreira',
    'Dom84',
    'Doman',
    'Draena',
    'dragnel',
    'DragonCat',
    'DrClap',
    'dreirik',
    'Dr .N0',
    'drq',
    'Dude named Jay',
    'duncanturk',
    'dw4y',
    'DWizzy',
    'dxdanny',
    'Eamonn',
    'ecotux',
    'edoardo',
    'Edward Fitzgerald',
    'EG',
    'e-gor',
    'EKS',
    'Element303',
    'ElfeDeMaison',
    'Elhaz',
    'eliott_lv',
    'elois',
    'EloiStree',
    'Elvith',
    'emeraldimp',
    'Emil',
    'Emilien',
    'Emma Blink',
    'eparthui',
    'Eric',
    'ErickM',
    'Ericounet',
    'Erik Lundin',
    'Erwan ',
    'ErwanC',
    'Etam',
    'etienne',
    'Ewen',
    'eyecreate',
    'Fabien G',
    'fabienli',
    'Fanch29',
    'fanetk',
    'f_bohmann',
    'Felipe - IMAGO',
    'ffreling',
    'firud',
    'Flabazoola',
    'flamme-demon',
    'flavio590',
    'Flip',
    'flo_dumax',
    'Florent Becker',
    'Florent F',
    'Florent Vln',
    'fmo',
    'fmt',
    'Follombre',
    'fprocess',
    'Framalove',
    'François LASSELIN',
    'francou',
    'Franklin',
    'freakynit',
    'FredBezies',
    'Frederic Dreuilhe',
    'Fredo',
    'FreeBooteR',
    'freecadfrance',
    'freeman',
    'frenchhope',
    'frnx',
    'F . Teppich',
    'FugazziPL',
    'funwhilelost',
    'Fuunnx ',
    'g1smo',
    'G4RUF',
    'Gabriel',
    'gael',
    'GaetanIllustration',
    'galaipa',
    'Galuel',
    'gdk21',
    'gecko64',
    'GégéLèze',
    'Gelth',
    'Genz',
    'Géo07',
    'Geoflly',
    'georgesk',
    'Germs',
    'GestiXi',
    'ggueyraud',
    'ghis',
    'Gidi',
    'gikari',
    'gileri',
    'Gilles Bonnet',
    'Gilou',
    'giocomai',
    'GllmR',
    'gmaill',
    'gnni',
    'gnuletik',
    'gobule',
    'GORF',
    'GotExx',
    'Govi',
    'Grapin',
    'gregtaole',
    'grimfa',
    'Gtkill & Kdosh',
    'GuePE',
    'guilg',
    'Guillaume',
    'Guillaume Slash',
    'gwado',
    'gwalarn',
    'gwarf',
    'Gwenlune',
    'Gyldenro',
    'h30x',
    'Hactarus',
    'HamsterJ',
    'Hans Cronau',
    'Harald Eilertsen',
    'Henk',
    'henne25',
    'Hethukawa',
    'Hintonsb',
    'Holden Lewis',
    'Hopiu',
    'höstelos',
    'houdini',
    'hougo',
    'HTeuMeuLeu',
    'hubz',
    'hugues de keyzer',
    'Iceman',
    'IIIIIIII',
    'ikcalb',
    'Ikuso',
    'imacrea',
    'Inhji',
    'IPv7',
    'itai',
    'itsfoss',
    'jackp',
    'jacopatrolman',
    'Jan',
    'jan_j',
    'Janjko',
    'Jason',
    'Jay',
    'jazzibao',
    'jcfrog',
    'jclejalu',
    'JCyn',
    'Jean',
    'Jean-Fred',
    'Jeena',
    'Jeremy Crowe',
    'Jeroen',
    'Jerome',
    'Jérôme L',
    'jerume',
    'JerwuQu',
    'jfc',
    'jfsimon',
    'jhammons',
    'jibidev',
    'Jigme Datse Yli-Rasku ',
    'JJFlash',
    'jlin',
    'jmh74',
    'jmuller',
    'jnoel',
    'J . N . Squire',
    'joachim',
    'Joe',
    'Joel L',
    'johannes',
    'John Tiesselune',
    'Jomn',
    'Jonathan DUPRE',
    'jonny',
    'JoPatate',
    'joselito1967',
    'JosephK',
    'Joxemi',
    'Joy',
    'jpfox',
    'jrballesteros05',
    'Ju_',
    'Juanxmass',
    'ju .bonhomme',
    'Julian7',
    'Julien',
    'JulienB',
    'JulienF',
    'jvarro',
    'jz',
    'k0n24d',
    'Kaladaran',
    'kalou',
    'Kaopics',
    'Kapu',
    'Karibu',
    'Kazhan',
    'keltia22',
    'Ken',
    'KevH123',
    'Kevin',
    'Kévin Dunglas',
    'Kill2BlooD',
    'kiriakos',
    'Klo',
    'Koala Yeung',
    'Kody',
    'Kollektivet',
    'Korko',
    'Krysztophe',
    'Kurt Kremitzki',
    'l33ter',
    'la hyène vegan',
    'Lambdanaut',
    'Lanza',
    'L\'Arakido',
    'Largo43',
    'Larknight',
    'larma',
    'laudeon',
    'Laura7089',
    'Laurence',
    'Laurent',
    'laurent2020',
    'Lbnt',
    'Ldm',
    'Lea',
    'LecygneNoir',
    'Leo_G',
    'Leonard',
    'leovaldecasas',
    'lepetitbonnetrouge',
    'L\'EtatPaiera-ManuMacron-16-03-2020',
    'Lexi',
    'lhp22',
    'librelois',
    'lightonflux',
    'lili',
    'liluminus',
    'L\'intendant zonard',
    'linuxmario',
    'Loik56',
    'lolo26130',
    'Lorca',
    'Louis',
    'Louis G .',
    'louis roche',
    'LPS',
    'LSV',
    'lub',
    'Luc',
    'lucas',
    'Lucy',
    'Lurik',
    'lusoheart',
    'lw1_at',
    'Mac_Bm',
    'Macro',
    'madko',
    'madsugar',
    'MaëvaC',
    'mamyn0va',
    'Manette',
    'Maraninx',
    'marcel',
    'marc f .',
    'Marc-GASSER',
    'Marcok',
    'mariesosa',
    'Martijn',
    'Martin',
    'Marud',
    'Maruho',
    'MaSven',
    'MatejLach',
    'matf',
    'matiaslavik',
    'matieu',
    'matlag',
    'Matthieu',
    'Matthieu Blanco',
    'Matthieu Schneider',
    'Mattis Blake',
    'Mäusle aus Herbtown',
    'maxamieux',
    'MayeulC',
    'mazgab',
    'mdegoys',
    'Megad',
    'meil',
    'mhep',
    'Michael Hund',
    'Michel_V',
    'micka',
    'mickeymtp',
    'MickGe',
    'minhducdoo',
    'Minou',
    'mireille',
    'Mirek',
    'mithiriath',
    'MM',
    'mnalis',
    'modestmax',
    'MonkeyMatt',
    'montaropdf',
    'Morbid',
    'Moritz Dietz',
    'Moul',
    'mrflos',
    'MrManor',
    'Mr .S',
    'Mr . Saladfingers',
    'MrTeeXD',
    'MTP',
    'Munch Munch',
    'MyMoi',
    'NaejDoree',
    'Nargasse',
    'Nartagnan',
    'ndurchx',
    'neko',
    'neodarz',
    'NeroKyusi',
    'Nesvep',
    'neverything',
    'Nicolas',
    'nicolasa',
    'nilocram',
    'Nils',
    'nishil',
    'Nitai',
    'njin',
    'nogajun',
    'Nomagic',
    'Normandy',
    'notanamber',
    'Nouts',
    'Nozof',
    'Nulani t\'Acraya',
    'Odd_Bloke',
    'oiseauroch',
    'ok3z',
    'Okki',
    'Oliv\'',
    'Olivier C .',
    'Olwë',
    'open mastering',
    'openworld',
    'oric',
    'Orignal',
    'Ostapenko',
    'paddatrapper',
    'Panos Alevropoulos',
    'Panpan',
    'Pantoufle',
    'Panxatony',
    'parisni',
    'Pascoual',
    'pasdavoine',
    'paul',
    'Paul Argoud',
    'paulfd',
    'Paul-Louis Ageneau',
    'pbramy',
    'pcazeneuve',
    'pcet',
    'pconin',
    'pederdm000',
    'Peertube BE',
    'PeerTube .dk',
    'peperonipizza',
    'peperunas',
    'Pere MP',
    'Pertone',
    'PeterJoe',
    'peterwolf',
    'Phie',
    'philippe lhardy',
    'pierreb',
    'Pierre Bresson',
    'Pierre Licier',
    'Pikselkraft',
    'Pingolin',
    'pitbuster',
    'pluricité',
    'plv',
    'Pocket',
    'Pof34',
    'Polughi',
    'povey',
    'PP44',
    'pparent',
    'ppom',
    'ProutRuby',
    'publicvoit',
    'punkylibre',
    'pvllnv',
    'pyratebeard',
    'quentin',
    'R',
    'Rafael Caricio',
    'Rafe',
    'Ragarnoy',
    'Raphaël Brocq',
    'Rascar Capac',
    'Raydians',
    'RaymondLaScience',
    'Redmood',
    'refragable',
    'Rémi ',
    'Rémi',
    'remiforall',
    'Remiforall',
    'renau',
    'revolunet',
    'rhitakorrr',
    'rick',
    'Rick',
    'Rita-G .P',
    'R .Ludwig',
    'RobertDouglass',
    'robertgzr',
    'RobinF',
    'robosanta',
    'Rodolphe B .',
    'roipoussiere',
    'Rolus',
    'rom1',
    'Romain',
    'Romain Deffayet',
    'Ronan29',
    'roptat',
    'Rubujeto',
    'Rumblestiltskin',
    'rumpelsepp',
    'rupicapra',
    'Ruslanas Gzibovskis',
    'Sacha',
    'sacrediou',
    'Salamandar',
    'samae',
    'Sarcasm Stardust',
    'Sardo Ip',
    'saxattax',
    'Sbgodin',
    'SCANI',
    'schorsch',
    'Schröd',
    'scrchngwsl',
    'Seballot',
    'sébas',
    'Sebastià',
    'Sébastien Adam',
    'Seboss666',
    'sefau',
    'selea',
    'Septie',
    'Servant Wolf',
    'shangka',
    'Shaun',
    'Shiftee',
    'Shiipou',
    'Shika',
    'Sibervlc',
    'Sibiar',
    'Siegfried Ehret',
    '[Sim]',
    'Sim',
    'Simon',
    'simorange',
    'sinnere',
    'Sir_Hautdesrables',
    'skadge',
    'Skia',
    'sleeproll',
    'SMART',
    'SNiCA',
    'Solene',
    'Som',
    'Soraphiroth',
    'sossa',
    'SourceHut',
    'soyuka',
    '@sozialwelten@ifwo .eu',
    'SpatMan',
    'spe',
    'spectio',
    'Spokester',
    'Spydemon',
    'Starsie',
    'Stenanais',
    'stephane-klein',
    'stephenyeong',
    'stevenroose',
    'StHo',
    'Stumpi',
    'sub26nico',
    'sw',
    'Sylphio',
    'Sylvain Cabra',
    'Sylvain Glaize',
    'Syst',
    'szasza',
    'taiprogramer',
    'tarball',
    'tenroc',
    'Terrywho',
    'tfardet',
    'Theos3',
    'TheZoq2',
    'Thibault',
    'Thibault Lemaire',
    'ThierryM',
    'Thomas Kuntz',
    'thomas magnum',
    'thomas Mill',
    'Thor',
    'Thorbardine',
    'thuck',
    'tibo',
    'Tibs245',
    'tiennotg',
    'TIfriis',
    'Till Parisot',
    'Tim',
    'timeKeeperXCII',
    'Timo',
    'tintou',
    'tirz',
    'tistbajean',
    'titi',
    'tj_314',
    'Tjiho',
    'TkPx',
    'tlestsang',
    'Toad',
    'toaskoas',
    'Tobias E***',
    'Togart',
    'toine',
    'toliger',
    'tollyx',
    'Tolstoevsky',
    'tom79',
    'tomasekeli',
    'Tomus',
    'Tom Wor',
    'Tonton Ayo',
    'TopherIsSwell',
    'Toubba',
    'Tr4sK',
    'trankilloman',
    'Trésorier Oisux',
    'triou',
    'troll',
    'TROMsite .com',
    'truscellino',
    'tsukasagenesis',
    'tuckerm',
    'Tugaleres .com',
    'Turbulent-Student',
    'Tursiops',
    'Tutux84',
    'twinkybot',
    'TychoCelchu',
    'tykayn',
    'tytan652',
    'uglyhack',
    'Unicorn',
    'Vainamoinen',
    'val',
    'valentin b',
    'Valerie',
    'vancha',
    'vanecx',
    'Vazquez',
    'vcris',
    'vdgergo',
    'VegaFjord',
    'ves ',
    'Vinay',
    'Vince',
    'Vincent Cloutier',
    'vincentlc',
    'vincentxavier',
    'Vir Ghygie',
    'VirtuBox',
    'Vison',
    'w95psp',
    'Waazdakka',
    'Walter Ebert',
    'web13tv',
    'WEBmadman ',
    'wildcat',
    'Wiz',
    'wmussack',
    'Wydow',
    'Xavier Normant',
    'Xenthys',
    'xhoffi',
    'Xipiryon',
    'Xobs',
    'Xof',
    'xtofme',
    'ykweyer',
    'Yod4z',
    'yogthos',
    'yopox',
    'YuyaSelena',
    'yva',
    'yznnig',
    'zac west',
    'Zak',
    'Zakadrine',
    'zangakyu',
    'Zar',
    'Zeiko',
    'ZelphirKaltstahl',
    'Zlaxx',
    'Zordhak',
    'Zoyolin',
    'zwindler',
    'Сергей Аргов'
  ]
}

function get2018CrowdfundingContributors () {
  return [
    'Quonfucius',
    'IP',
    'Laure',
    '@lex666',
    '0x010C',
    '3dsman',
    '3rw4n-G3D',
    'aallrd',
    'Abel-Berger',
    'Adam-Odell',
    'adechambost',
    'adim',
    'adngdb',
    'Adrien',
    'Adrien-BARAN',
    'Adrien-Hamraoui',
    'Adrien-Horcholle',
    'Adrien-Luxey',
    'Adrien-Polar',
    'Adrien-Touminet',
    'Agathe',
    'Agence-Différente',
    'Ahmed-Al-Ahmed',
    'aiprole',
    'akpoptro',
    'Al-Nimr',
    'Alain-Delgrange',
    'Alain-Fyon',
    'Alain-Girard',
    'Alain-MICHEL',
    'Aleksandar-Aleksandrov',
    'Alex-Chancellé',
    'Alex-Dufournet',
    'Alex-Gleason',
    'Alexander-Murray-Watters',
    'Alexandre-Alapetite',
    'Alexandre-Badez',
    'Alexandre-Giuliani',
    'Alexandre-Mercier',
    'Alexandre-Roux-2',
    'Alexandre-SIMON',
    'Alexandre29',
    'Alexia-Monsavoir',
    'Alexis-Frn',
    'Alexis-Gros',
    'Alexis-Kauffmann',
    'alfajet',
    'Alias',
    'alinemont',
    'Aliocha-Lang',
    'Alllightlong',
    'aloisdg',
    'Amanda',
    'André-Rabe',
    'Anne-PROTAS',
    'antoine',
    'Antoine',
    'Antoine-Beauvillain',
    'Antoine-Deléron',
    'antomoro,Antón',
    'Antonin-DENIS',
    'Antonin-Segault',
    'aokami',
    'Apichat-Apichat',
    'Ar-To',
    'ARIAS-Frédéric-2',
    'ariasuni',
    'Aris-Papathéodorou',
    'Arnaud',
    'Arnaud-Mounier',
    'Arnaud-Risler',
    'Arnaud-Vigouroux',
    'Arnulf',
    'Arthur-Bellier',
    'arthur-bello',
    'Arthur-Charron',
    'Arthur-De',
    'Arthur.Ball',
    'Arthur.Frin',
    'Arvi-LEFEVRE',
    'athanael .fr',
    'auber38',
    'Auguste',
    'Aurélien-Tamisier',
    'Avel-Musicavel',
    'axel-guegant',
    'Axel-Plat',
    'Aymeric-Dlv',
    'Ayst,Azenilion',
    'Bandino',
    'baptiste-lemoine',
    'Baptiste-Rochez',
    'baruica',
    'Bastien-Dangin',
    'batlab',
    'bcourtine',
    'Bea-Schaack-2',
    'beaufils',
    'beaumme',
    'Belmont1',
    'Ben-Geeraerts',
    'Ben-Meijering',
    'Benjamin-Baratta',
    'Benjamin-Roussel',
    'Benoît',
    'Benoîtdd',
    'Bernard-Legrand',
    'Bernard-Vauquelin',
    'Bernhard-Hayden',
    'bertrand.arlabosse',
    'bigsicret',
    'bjg',
    'bnjbvr',
    'bob_isat',
    'bobstechsite',
    'Bolton-Allan',
    'Boov\'',
    'Boris-ARGAUD',
    'Brice.Francois',
    'broz42',
    'Bruno',
    'Bruno-Douville',
    'Bruno-Fortabat',
    'Bruno-Gadaleta',
    'Bruno-VASTA',
    'Bumblebee',
    'Butchcassidy',
    'Cadiou-Christophe',
    'calendros',
    'Candy-Ming',
    'cappitaine',
    'Carmen-Drocourt',
    'carrigns',
    'case',
    'Cathy-Barbet',
    'CBach',
    'ccazin',
    'Cecile-Obernesser',
    'Cecilia-:)',
    'Cédric-Bleschet',
    'Cédric.Bayle',
    'Cestdoncvrai',
    'cgay',
    'champ',
    'chapa',
    'charlerlin',
    'charles-jacquin',
    'Charlie-Duclut',
    'charlotte-cgondre78',
    'Chris-Doe',
    'chris-louba',
    'Christel-Berthelot',
    'Christian-FERRARIS',
    'christiannavelot',
    'Christophe-Bastin',
    'christophe-beziers',
    'Christophe-Pieret',
    'Christophe-Verhaege',
    'christophec',
    'Christopher-Bero',
    'chtfn',
    'chud',
    'Claire-C',
    'clairezed',
    'Claude-POUGHEON',
    'Clément-Hubert',
    'Clément-Morelle',
    'clydeb',
    'Comamanel',
    'Côme',
    'Confederac .io',
    'Consulting-AZAPTEC',
    'Corentin3892',
    'CryoGen',
    'cyp',
    'Cypher-Goat',
    'Cyril',
    'Cyril_M_',
    'Cyril-MONMOUTON',
    'Cyril-Waechter',
    'Damien-Gabard',
    'Damien-Garaud',
    'Dams3132',
    'Daniel',
    'Daniel',
    'Daniel-Bartsch',
    'Daniel-PIPALA',
    'Daniel-Struck',
    'Daniel-Thul',
    'Danny-Joerger',
    'DansLeRuSH',
    'DantSu',
    'Dany-Marcoux',
    'Daouzli-Adel',
    'Darfeld',
    'Darth_Judge',
    'Dashcom',
    'David-BADOIL',
    'David-Benoist',
    'David-Dormoy',
    'David-Gil-2',
    'David-Velasco',
    'David-Wagner',
    'David-writ',
    'davlgd',
    'davyg2',
    'dbudo72300',
    'de',
    'DeBugs',
    'Denis-Lecourtiller',
    'Denis-Vannier',
    'Desmu',
    'Didier-Bove',
    'Diego-Crespo',
    'Dimitri-Stouney',
    'dino',
    'Dinosaure',
    'Doc',
    'Dominique-Brun',
    'dr4Ke',
    'DreamClassier',
    'DRogueRonin',
    'dussydelf',
    'Dylan-Moonfire',
    'Ealhad',
    'Edouard-SCHWEISGUTH',
    'Elanndelh--',
    'ElodieEtJimmy',
    'Éloi-Rivard',
    'Elric-Noel',
    'Elwan-Héry',
    'Emilie-Wietzke',
    'Emilien-Ghomi',
    'eparth',
    'Eric-Bouhana',
    'Eric-Hendricks',
    'Eric.Vales',
    'Erwan-Moreau',
    'Erzender',
    'ESS_Clem',
    'Etienne-Baqué',
    'Etienne-Botek',
    'Etienne-Lmn',
    'Ex-Serv,fabeveynes',
    'Fabien',
    'Fabien',
    'Fabien-Roualdes',
    'Fabien.Abraini',
    'Fabien.Bonneval',
    'fabrice-simon',
    'farlistener',
    'Felix-ROBICHON',
    'FelixDouet',
    'FHE',
    'Fiamoa-McBenson',
    'flamwenco',
    'Flopômpôm',
    'FloraGC',
    'Florent-Deschamps',
    'Florent-Fayolle',
    'Florent-Mallet',
    'Florent-Vasseur',
    'Florent.Duveau',
    'Florestan',
    'Florian',
    'Florian-Bellafont',
    'Florian-Douay',
    'Florian-LE',
    'Florian-Siegenthaler',
    'Florian.Freyss',
    'fobrice',
    'FOKUZA',
    'Fol-De',
    'FP45',
    'Francis.Moraud',
    'François-Dambrine',
    'François-Deguerry',
    'Francois-Goer',
    'François-Lecomte',
    'François-Lemaire',
    'François-Malterre',
    'François-MORLET',
    'François-Schoubben',
    'François-Xavier-Davanne',
    'François-Zajéga',
    'francois.peyratout',
    'Frathom',
    'Fred-Fred-2',
    'Frédéric',
    'Frédéric-Blumstein',
    'Frédéric-Meurou',
    'Frederic-Reynaud',
    'Frédéric-Sagot',
    'Frek',
    'FrenchHope',
    'freyja',
    'FugazziPL',
    'Funky-Whale',
    'Gabriel-Devillers',
    'Gabriel-Mirété',
    'Galedas',
    'GardoToF',
    'Gaspard-Kemlin',
    'GauthierPLM',
    'Gauvain',
    'Gavy',
    'gdquest,Geek',
    'Geneviève-Perello',
    'Geoffroy-MANAUD',
    'Geojulien',
    'Georges-Dutreix',
    'Georges-Sempéré',
    'Gerald-Vannier',
    'Gérard-Brasquet',
    'Gérard-Sensevy',
    'Gerrit-Großkopf',
    'GGBNM',
    'Ghislain-Fabre',
    'Gil-Felot',
    'Gilles-Brossier',
    'Gilles-Moisan',
    'Gilles-SACLIER',
    'Gilles-Trossevin',
    'Gilou',
    'GinGa',
    'ginkgopr',
    'glazzara',
    'Glen-Lomax',
    'Gof',
    'Gonçalves-Daniel',
    'goofy-goofy',
    'grandlap',
    'GRAP-Groupement',
    'greg-chapuis',
    'Grégoire-Delbeke',
    'Grégory-Becq',
    'Grégory-Goulaouic',
    'Gregouw',
    'Grizix',
    'GrosCaillou',
    'Grummfy',
    'grumph',
    'guiaug',
    'Guillaume-Allart',
    'Guillaume-Chambert',
    'Guillaume-Chaslot',
    'Guillaume-David',
    'Guillaume-Duc',
    'Guillaume-Gay',
    'Guillaume-Lecoquierre',
    'Guillaume007',
    'guillaumefavre',
    'Guiraud-Dominique,Guy-Torreilles',
    'GwendalL',
    'gwlolos',
    'Hanna-E',
    'Hanno-Wagner',
    'Harald-Eilertsen',
    'Harpocrate',
    'Hebus82',
    'Hellmut',
    'Henri-ROS',
    'hervelc',
    'hguilbert',
    'Hisham-Muhammad',
    'Hoang-Mai-Lesaffre',
    'Homerc',
    'homosapienssapiens',
    'hoper',
    'Hoshin',
    'Hugo-Lagouge',
    'Hugo-SIMANCAS',
    'Hugo-Simon',
    'Hylm',
    'IchbinRob',
    'Ivan-Ogai',
    'Ivan.D\'halluin',
    'Ivar-Troost',
    'J-C-2',
    'Jacques-Roos',
    'James-Moore',
    'James-Valleroy',
    'Jan-Aagaard',
    'Jan-Keromnes',
    'Jancry',
    'Janko-Mihelić',
    'jano31coa',
    'Jboot',
    'jcgross',
    'Jean',
    'jean',
    'Jean',
    'jean',
    'Jean-Baptiste-Maneyrol',
    'Jean-charles-Surbayrole',
    'Jean-claude-Jouanne',
    'jean-dreyfus',
    'jean-FISCHER',
    'JEAN-FRANCOIS-BOUDEAU',
    'Jean-Francois-Ducrot',
    'Jean-François-PETITBON',
    'Jean-François-Tomasi',
    'Jean-Galland',
    'Jean-louis-Bergamo',
    'Jean-Luc-PIPO',
    'Jean-Marie-Graïc',
    'Jean-Martin',
    'Jean-Noel-Bruletout',
    'Jean-Paul-GIBERT',
    'Jean-Paul-Lescat,jean-philippe-bénétrix',
    'Jean-Philippe-Eisenbarth',
    'Jean-Philippe-Renaudet',
    'Jean-Philippe-Rennard',
    'Jean-Sébastien-Renaud',
    'Jean-Yves',
    'Jean-Yves-DUPARC',
    'Jeanne-Corvellec',
    'jeansebastien',
    'Jelv',
    'Jérémie',
    'Jeremie-Lestel',
    'Jérémy-Korwin',
    'Jérôme-Avond',
    'Jerome-Bu',
    'Jerome-Denis',
    'Jérôme-ISNARD',
    'jerome-simonato',
    'JeromeD',
    'Jery',
    'Jezza',
    'Jim-McDoniel',
    'jl-M-2',
    'jlanca',
    'jlcpuzzle',
    'jn-m',
    'jnthnctt',
    'joakim.faiss',
    'Joe-Riche',
    'Joévin-SOULENQ',
    'Johann-FONTAINE',
    'John-Devor',
    'John-Doe',
    'Jojo-Boulix',
    'Jonas-Aparicio',
    'Jonathan-Dollé',
    'Jonathan-Kohler',
    'Jonathan-LAURENT',
    'Jos-van',
    'Joseph-Lawson',
    'Jozef-Knaperek',
    'jroger',
    'ju',
    'jubarbu',
    'Julianoe-G',
    'Julie-Bultez',
    'Julien',
    'Julien',
    'Julien-AILHAUD',
    'Julien-Aubin',
    'Julien-Biaudet',
    'Julien-Bréchet',
    'Julien-Cochennec',
    'Julien-Duroure',
    'Julien-Huon',
    'Julien-Lemaire',
    'Julien-Weber',
    'jyb',
    'K-',
    'KalambakA',
    'Kanor',
    'kari-kimber',
    'Karim-Jouini',
    'karl-bienfait',
    'Kdecherf',
    'Keplerpondorskell',
    'kevin-Beranger',
    'Kevin-Nguyen',
    'King-Of',
    'Kioob',
    'kloh',
    'kokoklems',
    'Konstantin-Kovar',
    'Kriĉjo',
    'Kyâne-PICHOU',
    'L\'elfe-Sylvain',
    'La',
    'Lara-Dufour',
    'lareinedeselfes',
    'Laurence-Giroud',
    'laurent-fuentes',
    'Laurent-HEINTZ',
    'Laurent-PICQUENOT',
    'ldubost',
    'lebidibule',
    'LeChi',
    'LeDivinBueno',
    'Legrave',
    'Les',
    'Leyokki-Tk',
    'LibreEnFete-en',
    'LilO.',
    'Liloumuloup',
    'Linuxine-T',
    'lionel-lachaud',
    'Lionel-Schinckus',
    'Loïc-L\'Anton',
    'Loïc.Guérin',
    'Louis-Gatin',
    'Louis-Marie-BAER',
    'Louis-Rémi.Babé',
    'Louis-Roche',
    'Louisclement',
    'Lu',
    'ludovic-lainard',
    'Ludovic-Pénet',
    'Lukas-Steiblys',
    'lusoheart',
    'Mad',
    'maguy-giorgi',
    'mahen',
    'maiido',
    'Malphas',
    'ManetteBE',
    'Manon-Amalric',
    'Manuel-Vazquez',
    'ManuInzesky',
    'Manumerique',
    'Marc-BESSIERES',
    'Marc-DUFOURNET',
    'Marc-GASSER',
    'Marc-Honnorat',
    'marc-wilzius',
    'marc.ribault.1',
    'Marco-Heisig',
    'Marie-PACHECO',
    'Marien-Fressinaud',
    'Marius-Lemonnier',
    'Mark-O\'Donovan',
    'marliebo',
    'marmat8951',
    'mart1n',
    'martensite',
    'Mathdatech',
    'Mathias-Bocquet',
    'Mathieu-Amirault',
    'Mathieu-B.',
    'Mathieu-Cornic',
    'Mathieu-VIRAMAN',
    'Matías-Pérez',
    'Matilin-Torre',
    'matt.faure,Mattéo-Delabre',
    'Matthias-Devlamynck',
    'Matthieu-Bollot',
    'Matthieu-De',
    'Matthieu-DEVILLERS',
    'Matthieu-Dupont',
    'Matthieu-Gaudé',
    'Matthieu-Sauboua-Beneluz',
    'matthieublanco',
    'MatthieuSchneider',
    'Max-PENY',
    'Maxime-de',
    'Maxime-Desjardin',
    'Maxime-Forest',
    'maxime-haag',
    'Maxime-Mangel',
    'Maximilian',
    'Mayeul-Cantan',
    'Mayeul-Guiraud',
    'mcg1712',
    'metalvinze',
    'Mewen',
    'mheiber',
    'Michael-Koppmann',
    'Michael-Loew',
    'Michael-Q.',
    'Michal-Herda',
    'Michal-Noga',
    'Michel-DUPONT',
    'Michel-Le',
    'Michel-POUSSIER',
    'Michel-Roux',
    'Mickaël-Gauvin',
    'Mickael-Liegard',
    'MicMP3Man',
    'Miguel-de',
    'Mike-Kasprzak',
    'Mimon-Lapompe',
    'Mister-Ocelot',
    'mjhvc',
    'Moutmout',
    'MouTom',
    'MP',
    'mphdp',
    'Mr-Tea',
    'msellebulle',
    'Mushussu',
    'mylainos',
    'nanouckd',
    'Nasser-Debruyere',
    'Nat-Tuck',
    'Nathan.B',
    'nayya',
    'nazgulz666',
    'Neal-Wilson',
    'neeev',
    'neodarz-neodarz',
    'NepsKi',
    'Nestorvep',
    'NHenry',
    'Nialix',
    'NicoD',
    'Nicolas-Auvray',
    'nicolas-k',
    'Nicolas-Pinault',
    'Nicolas-Ruffel',
    'NicolasCARPi',
    'nicolaslegland',
    'niconil',
    'Niles',
    'nitot',
    'Nono1965',
    'Norbert',
    'Norde',
    'Numcap',
    'obergix',
    'Obrow',
    'Okki',
    'Olivier-Calzi',
    'Olivier-Ganneval',
    'Olivier-Marouzé',
    'Olivier-Mondoloni',
    'olivier-pierret',
    'Oncela-Petit',
    'Óskar-Sturluson',
    'p3n15634n7',
    'Paindesegle',
    'Pas',
    'Pascal-BLEUSE',
    'Pascal-Larramendy',
    'Patrice-Jabeneau',
    'patrice-maertens',
    'patrick-bappel',
    'PATRICK-GRANDIN',
    'Patrick-MERCIER',
    'Patrickl',
    'Paul-Härle',
    'Paul-Tardy',
    'pbramy',
    'Pedro-CADETE',
    'Perrine-de',
    'Peter_Fillgod',
    'Petter-Joelson',
    'Philippe-BATTMANN',
    'Philippe-Cabaud',
    'Philippe-Debar',
    'philippe-giffard',
    'Philippe-Lallemant',
    'Philippe-Le',
    'philippe-lhardy',
    'Philippe-Thébault',
    'Philippe-VINCENT-2',
    'PhilOGM',
    'Pierre',
    'Pierre',
    'Pierre-Antoine-Champin',
    'Pierre-Bresson-2',
    'Pierre-d\'Alençon',
    'Pierre-Equoy',
    'Pierre-Girardeau',
    'Pierre-Houmeau',
    'Pierre-Marijon',
    'Pierre-petch',
    'Pierrick-Couturier',
    'Pilou-CaraGk',
    'Piotr-Miszczak',
    'Pla',
    'PlasticYogi',
    'PME2050',
    'pmiossec',
    'Pofilo',
    'Polioman',
    'Polios63',
    'Poutchiny',
    'PRALLET-Claude',
    'PtrckVllnv',
    'Pulov',
    'queertube',
    'Quentin-Dugne',
    'Quentin-PAGÈS',
    'ra-mon',
    'Radhwan-Ben',
    'Raphaël-Brocq',
    'Raphaël-Grolimund',
    'Raphaël-Piédallu',
    'raphane',
    'Raphip',
    'Raven',
    'Raymond-Lutz',
    'Razael',
    'Rebecca-Breu',
    'Remi-Durand',
    'Rémi-Herrmann',
    'Rémi-Verschelde',
    'Remigho',
    'Remix-the',
    'Remy-Grauby',
    'Rémy-Pradier',
    'Renaud-Vincent',
    'rgggn',
    'rigelk',
    'rip',
    'Rivinbeg',
    'Robert-Riemann',
    'Robin',
    'Roger-FRATTE',
    'roipoussiere',
    'Rolindes-Arroyo',
    'Romain',
    'Romain-Bouyé',
    'Romain-Ortiz',
    'RomainVENNE',
    'Romuald-EYRAUD',
    'royhome',
    'Rudy-aparicio',
    'Rusty-Dwyer',
    'rverchere',
    'sajous .net',
    'Salah-ZERGUI',
    'Sam-R',
    'Samh',
    'Samuel',
    'Samuel-FAYET',
    'Samuel-Verschelde',
    'Sanpi',
    'Sascha-Brendel',
    'Schwartz',
    'Se7h',
    'Sebastiaan-Glazenborg',
    'Sebastian-Hugentobler',
    'Sébastien',
    'Septie',
    'Ser',
    'Severin-Suveren',
    'severine-roger',
    'shlagevuk-shlagevuk',
    'Siegfried-Ehret',
    'Simon-Hemery',
    'Simon-Larcher',
    'Simon-Reiser',
    'Simounet',
    'Siri-Louie',
    'sissssou',
    'skarab',
    'Skurious',
    'skynebula',
    'Sohga-Sohga',
    'Solène-Rapenne',
    'solinux',
    'Sophie-Imbach',
    'Sosthen',
    'Spiderweak',
    'Stanislas-ANDRE',
    'Stanislas-Michalak',
    'starmatt',
    'Steef',
    'Stefan-Petrovski',
    'Stéphane-Girardon',
    'Stéphanie-Baltus',
    'Stev-3d',
    'Stoori',
    'SuckyStrike',
    'Sufflope',
    'Sulfurax',
    'SundownDEV',
    'Swann-Fournial',
    'Syk',
    'Syluban',
    'Sylv1c',
    'Sylvain',
    'Sylvain',
    'Sylvain_M',
    'Sylvain-Cazaux',
    'Sylvain-GLAIZE',
    'sylvain.arrachart',
    'Sylvestre',
    'sylvie-boutet',
    'Sylvie-TORRES',
    'tael67',
    'tang35',
    'tangi_b',
    'Tarulien',
    'Taunya-Debolt',
    'Tazimut-Khaelyor',
    'terry-maire',
    'Thanaen',
    'Thatoo',
    'Théophile-Noiré',
    'Thibault-Vlieghe',
    'Thierry-Chancé',
    'Thierry-Fenasse',
    'Thomas-Aurel',
    'Thomas-CALVEZ',
    'thomas-constans',
    'Thomas-Kuntz',
    'thomassin-loucas',
    'Thosbk',
    'ticosc',
    'Tim-Albers',
    'Tinapa',
    'TkPx',
    'TM',
    'tnntwister',
    'TomR',
    'Tomus',
    'Tonio-Bilos',
    'tony-carnide',
    'Toover',
    'toto-leroidelasaucisse',
    'ToumToum',
    'TP.',
    'trigrou',
    'Tristan-Porteries',
    'Tryph',
    'Tursiops',
    'tzilliox',
    'U-&_`HbAAe4onnpN9!e+/#425>k^E',
    'Ulrich-Norbisrath',
    'Un',
    'Valerio-Paladino',
    'Valerio-Pilo',
    'Valeryan_24',
    'Valou69',
    'Vegattitude',
    'Velome',
    'Vergogne',
    'Vero-Pajot',
    'vianneyb',
    'Victo-Sab',
    'Victor',
    'Victorien-Labalette',
    'Vincent-Corrèze',
    'Vincent-Fromentin',
    'Vincent-Lamy',
    'Vincent-Lasseur',
    'VINCENT-PEYRET',
    'vmorel',
    'Walter-van',
    'Watsdesign',
    'Wesley-Moore',
    'williampolletdev',
    'win100',
    'wyk',
    'Xaloc-Xaloc',
    'Xavier',
    'Xavier-Chantry',
    'Xavier-Godard',
    'XoD',
    'Yaaann',
    'Yann-Delaunoy',
    'Yann-Nave',
    'yannick-grenzinger',
    'yanselmetti',
    'Ykatsot',
    'Yohann-Bacha',
    'yopox',
    'Youen-Toupin',
    'Yves-Caniou',
    'Yves-Gerech',
    'zar-rok',
    'ZeBlackPearl',
    'ZeGreg'
  ]
}

// Zanata is dead, don't loose the contributors name
function getZanataContributors () {
  return [
    { username: 'abdhessuk', name: 'Abd Hessuk' },
    { username: 'abidin24', name: 'abidin toumi' },
    { username: 'aditoo', name: 'Lorem Ipsum' },
    { username: 'alice', name: 'Alice' },
    { username: 'anastasia', name: 'Anastasia' },
    { username: 'autom', name: 'Filip Bengtsson' },
    { username: 'balaji', name: 'Balaji' },
    { username: 'bristow', name: 'Cédric F.' },
    { username: 'butterflyoffire', name: 'ButterflyOfFire' },
    { username: 'chocobozzz', name: 'Chocobozzz' },
    { username: 'claichou', name: 'Claire Mohin' },
    { username: 'degrange', name: 'Degrange Mathieu' },
    { username: 'dibek', name: 'Giuseppe Di Bella' },
    { username: 'edu', name: 'eduardo' },
    { username: 'ehsaan', name: 'ehsaan' },
    { username: 'esoforte', name: 'Ondřej Kotas' },
    { username: 'fkohrt', name: 'Florian Kohrt' },
    { username: 'giqtaqisi', name: 'Ian Townsend' },
    { username: 'goofy', name: 'goofy' },
    { username: 'gorkaazk', name: 'Gorka Azkarate Zubiaur' },
    { username: 'gwendald', name: 'GwendalD' },
    { username: 'h3zjp', name: 'h3zjp' },
    { username: 'jfblanc', name: 'Joan Francés Blanc' },
    { username: 'jhertel', name: 'Jean Hertel' },
    { username: 'jmf', name: 'Jan-Michael Franz' },
    { username: 'jorropo', name: 'Jorropo' },
    { username: 'kairozen', name: 'Geoffrey Baudelet' },
    { username: 'kedemferre', name: 'Kédem Ferré' },
    { username: 'kousha', name: 'Kousha Zanjani' },
    { username: 'krkk', name: 'Karol Kosek' },
    { username: 'landrok', name: 'Landrok' },
    { username: 'leeroyepold48', name: 'Leeroy Epold' },
    { username: 'm4sk1n', name: 'marcin mikołajczak' },
    { username: 'matograine', name: 'tom ngr' },
    { username: 'medow', name: 'Mahir Ahmed' },
    { username: 'mhu', name: 'Max Hübner' },
    { username: 'midgard', name: 'Midgard' },
    { username: 'nbrucy', name: 'N. B.' },
    { username: 'nitai', name: 'nitai bezerra' },
    { username: 'noncommutativegeo', name: 'Andrea Panontin' },
    { username: 'nopsidy', name: 'McFlat' },
    { username: 'nvivant', name: 'Nicolas Vivant' },
    { username: 'osoitz', name: 'Osoitz' },
    { username: 'outloudvi', name: 'Outvi V' },
    { username: 'quentin', name: 'Quentí' },
    { username: 'quentind', name: 'Quentin Dupont' },
    { username: 'rafaelff', name: 'Rafael Fontenelle' },
    { username: 'rigelk', name: 'Rigel Kent' },
    { username: 's8321414', name: 'Jeff Huang' },
    { username: 'sato_ss', name: 'Satoshi Shirosaka' },
    { username: 'sercom_kc', name: 'SerCom_KC' },
    { username: 'severo', name: 'Sylvain Lesage' },
    { username: 'silkevicious', name: 'Sylke Vicious' },
    { username: 'sosha', name: 'Sosha' },
    { username: 'spla', name: 'spla' },
    { username: 'strubbl', name: 'Sven' },
    { username: 'swedneck', name: 'Tim Stahel' },
    { username: 'tagomago', name: 'Tagomago' },
    { username: 'talone', name: 'TitiAlone' },
    { username: 'thibaultmartin', name: 'Thibault Martin' },
    { username: 'tirifto', name: 'Tirifto' },
    { username: 'tuxayo', name: 'Victor Grousset/tuxayo' },
    { username: 'unextro', name: 'Ondřej Pokorný' },
    { username: 'unzarida', name: 'unzarida' },
    { username: 'vincent', name: 'Vincent Laporte' },
    { username: 'wanhua', name: 'wanhua' },
    { username: 'xinayder', name: 'Alexandre' },
    { username: 'xosem', name: 'Xosé M.' },
    { username: 'zveryok', name: 'Nikitin Stanislav' },
    { username: '6543', name: '6543' },
    { username: 'aasami', name: 'Miroslav Ďurian' },
    { username: 'alidemirtas', name: 'Ali Demirtas' },
    { username: 'alpha', name: 'Alpha' },
    { username: 'ariasuni', name: 'Mélanie Chauvel' },
    { username: 'bfonton', name: 'Baptiste Fonton' },
    { username: 'c0dr', name: 'c0dr lnx' },
    { username: 'canony', name: 'canony' },
    { username: 'cat', name: 'Cat' },
    { username: 'clerie', name: 'Clemens Riese' },
    { username: 'curupira', name: 'Curupira' },
    { username: 'dhsets', name: 'djsets' },
    { username: 'digitalkiller', name: 'Digital Killer' },
    { username: 'dwsage', name: 'd.w. sage' },
    { username: 'flauta', name: 'Andrea Primiani' },
    { username: 'frankstrater', name: 'Frank Sträter' },
    { username: 'gillux', name: 'gillux' },
    { username: 'gunchleoc', name: 'GunChleoc' },
    { username: 'jaidedtd', name: 'Jenga Phoenix' },
    { username: 'joss2lyon', name: 'Josselin' },
    { username: 'kekkotranslates', name: 'Francesco' },
    { username: 'kingu', name: 'Allan Nordhøy' },
    { username: 'kittybecca', name: 'Rivka bat Tsvi' },
    { username: 'knuxify', name: 'knuxify' },
    { username: 'lapor', name: 'Kristijan Tkalec' },
    { username: 'laufor', name: 'Lau For' },
    { username: 'lstamellos', name: 'Loukas Stamellos' },
    { username: 'lw1', name: 'Lukas Winkler' },
    { username: 'mablr', name: 'Mablr' },
    { username: 'marcinmalecki', name: 'Marcin Małecki' },
    { username: 'mayana', name: 'Mayana' },
    { username: 'mikeorlov', name: 'Michael Orlov' },
    { username: 'nin', name: 'nz' },
    { username: 'norbipeti', name: 'NorbiPeti' },
    { username: 'ppnplus', name: 'Phongpanot Phairat' },
    { username: 'predatorix', name: 'Predatorix' },
    { username: 'robin', name: 'Robin Lahtinen' },
    { username: 'rond', name: 'rondnelly nunes' },
    { username: 'secreet', name: 'Secreet' },
    { username: 'sftblw', name: 'sftblw' },
    { username: 'sporiff', name: 'Ciarán Ainsworth' },
    { username: 'tekuteku', name: 'tekuteku' },
    { username: 'thecatjustmeow', name: 'Nguyen Huynh Hung' },
    { username: 'tmota', name: 'Tiago Mota' },
    { username: 'uranix', name: 'Michal Mauser' },
    { username: 'wakutiteo', name: 'Markel' },
    { username: 'wonderingdane', name: 'Nicolai Ireneo-Larsen' },
    { username: 'zeynepeliacik', name: 'Zeynep Can' }
  ]
}

function getContributorsBlacklist () {
  return {
    'Bigard Florian': true,
    'chocobozzz': true,
    'Rigel': true
  }
}
